@@ -25,7 +25,7 @@
 #include "oscartypeclasses.h"
 #include "oscarcontact.h"
 #include "contact.h"
-#include "kopete_export.h"
+#include "oscar_export.h"
 
 class QDomNode;
 
@@ -57,7 +57,7 @@ public:
 	Oscar::Client* engine();
 
 	/** Disconnects this account */
-	virtual void disconnect();
+	void disconnect() Q_DECL_OVERRIDE;
 
 	/**
 	 * Handle the various ways we can be logged off the oscar service
@@ -73,12 +73,12 @@ public:
 	/**
 	 * Fill the menu for this account
 	 */
-	virtual void fillActionMenu( KActionMenu *actionMenu ) = 0;
+	void fillActionMenu( KActionMenu *actionMenu ) Q_DECL_OVERRIDE = 0;
 
 	/**
 	 * Sets the identity this account belongs to
 	 */
-	virtual bool setIdentity( Kopete::Identity *ident );
+	bool setIdentity( Kopete::Identity *ident ) Q_DECL_OVERRIDE;
 
 	/** Set the server address */
 	void setServerAddress( const QString& server );
@@ -138,7 +138,7 @@ public:
 	 */
 	bool changeContactGroupInSSI( const QString& contact, const QString& newGroupName, bool autoAddGroup );
 
-public slots:
+public Q_SLOTS:
 	void slotGoOffline();
 
 	void slotGoOnline();
@@ -148,8 +148,8 @@ protected:
 	 * Adds a contact to a meta contact
 	 */
 	friend class OscarProtocol;
-	virtual bool createContact(const QString &contactId,
-		 Kopete::MetaContact *parentContact );
+	bool createContact(const QString &contactId,
+		 Kopete::MetaContact *parentContact ) Q_DECL_OVERRIDE;
 
 	/**
 	 * Protocols using Oscar must implement this to perform the instantiation
@@ -164,7 +164,7 @@ protected:
 
 	virtual QString sanitizedMessage( const QString& message ) const;
 
-protected slots:
+protected Q_SLOTS:
 
 	//! do stuff on login
 	virtual void loginActions();
@@ -200,7 +200,7 @@ protected slots:
 
 	void chatroomRequest( ChatRoomHandler* handler );
 
-signals:
+Q_SIGNALS:
 
 	void accountDisconnected( Kopete::Account::DisconnectReason reason );
 
@@ -218,7 +218,7 @@ private:
 
 	QList<QDomNode> getElementsByTagNameCI( const QDomNode& node, const QString& tagName ) const;
 
-private slots:
+private Q_SLOTS:
 	/** Handler from socket errors from a connection */
 	void slotSocketError( int, const QString& );
 
@@ -244,5 +244,3 @@ private:
 
 #endif
 
-//kate: tab-width 4; indent-mode csands;
-
